execline: the getcwd program
Keywords: execline command getcwd current working directory variable pwd

execline
Software
skarnet.org

# The `getcwd` program

`getcwd` stores its current working directory into a given environment variable, then executes a program.

## Interface

         getcwd var prog...

`getcwd` stores a fully resolved absolute path (i.e. without any `.. or symbolic link components) to its current working directory into the var variable, then execs into prog with its arguments.`

## Notes

- var must be given without a dollar !
- var must not contain `=`.
- Unlike the pwd POSIX command, `getcwd` does not depend on the PWD environment variable and will always exhibit the same behaviour.